"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import unittest

import MergeTicketingClient
from MergeTicketingClient.api.selective_sync_api import SelectiveSyncApi  # noqa: E501


class TestSelectiveSyncApi(unittest.TestCase):
    """SelectiveSyncApi unit test stubs"""

    def setUp(self):
        self.api = SelectiveSyncApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_selective_sync_configurations_list(self):
        """Test case for selective_sync_configurations_list

        """
        pass

    def test_selective_sync_configurations_update(self):
        """Test case for selective_sync_configurations_update

        """
        pass

    def test_selective_sync_meta_list(self):
        """Test case for selective_sync_meta_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
