"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import MergeTicketingClient
from MergeTicketingClient.model.webhook_receiver import WebhookReceiver
globals()['WebhookReceiver'] = WebhookReceiver
from MergeTicketingClient.model.paginated_webhook_receiver_list import PaginatedWebhookReceiverList


class TestPaginatedWebhookReceiverList(unittest.TestCase):
    """PaginatedWebhookReceiverList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPaginatedWebhookReceiverList(self):
        """Test PaginatedWebhookReceiverList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PaginatedWebhookReceiverList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
