"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import MergeTicketingClient
from MergeTicketingClient.model.role import Role
globals()['Role'] = Role
from MergeTicketingClient.model.paginated_role_list import PaginatedRoleList


class TestPaginatedRoleList(unittest.TestCase):
    """PaginatedRoleList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPaginatedRoleList(self):
        """Test PaginatedRoleList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PaginatedRoleList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
