"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from unittest.mock import MagicMock

import MergeTicketingClient
from MergeTicketingClient.model.priority_enum import PriorityEnum
from MergeTicketingClient.api_client import ApiClient


class TestPriorityEnum(unittest.TestCase):
    """PriorityEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPriorityEnum(self):
        """Test PriorityEnum"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PriorityEnum()  # noqa: E501

        # no tests for enums
        pass

if __name__ == '__main__':
    unittest.main()
