# flake8: noqa

"""
    Merge Ticketing API

    The unified API for building rich integrations with multiple Ticketing platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.1.1"

# import ApiClient
from MergeTicketingClient.api_client import ApiClient

# import Configuration
from MergeTicketingClient.configuration import Configuration

# import exceptions
from MergeTicketingClient.exceptions import OpenApiException
from MergeTicketingClient.exceptions import ApiAttributeError
from MergeTicketingClient.exceptions import ApiTypeError
from MergeTicketingClient.exceptions import ApiValueError
from MergeTicketingClient.exceptions import ApiKeyError
from MergeTicketingClient.exceptions import ApiException
